# Changelog Chicken 🐥

## Chicken 1.0.0

* Chicken chicken chicken chicken chicken chicken chicken.
* Chicken "1.0" chicken "Chicken".
* Chicken chicken chicken chicken, chicken chicken. Chicken!
* "Chicken of Conduct" chicken chicken.
